==> onefetch-2.16.0.tar.gz: onefetch-2.16.0/docs/README.ar.md <==
<h3 align="center"><img src="../assets/onefetch.svg" height="130px"></h3>

<h5 align="center">Rust مكتوبه بالغة GIT أداة سطر الأوامر لعرض معلومات مستودع</h5>

<p align="center">
	<a href="https://crates.io/crates/onefetch"><img src="https://img.shields.io/crates/v/onefetch.svg" alt="cargo"></a>
	<a href="https://github.com/o2sh/onefetch/actions"><img src="https://github.com/o2sh/onefetch/workflows/CI/badge.svg" alt="Build Status"></a>
  <a href="https://onefetch.dev"><img src="../assets/language-badge.svg"></a>
	<a href="https://github.com/o2sh/onefetch/issues?q=is%3Aissue+is%3Aopen+label%3A%22help+wanted%22"><img src="https://img.shields.io/github/issues/o2sh/onefetch/help%20wanted?color=green" alt="help wanted"></a>
	<a href="../LICENSE.md"><img src="https://img.shields.io/badge/license-MIT-blue.svg"></a>
	<img src="../assets/msrv-badge.svg">
</p>

<img src="../assets/screenshot-1.png" align="left" height="240px">

<p dir="rtl" lang="ar">
Onefetch
هي أداة سطر الأوامر مكتوبة بالغة
Rust
تعرض معلومات المشروع وإحصائيات الكود لمستودع
Git
.المحلي مباشرة الي جهازك الطرفي
الأداة مستقلة تمامًا عن الإنترنت - لا يتطلب الوصول إلى الشبكة.
</p>

<p dir="rtl" lang="ar">
يتم عرض معلومات المستودع جنباً إلي جنب مع شعار اللغة السائدة في المشروع بشكل إفتراضي، ولكن يمكنك أيضاً تكوين
Onefetch
بحيث يستخدم بدلاً من ذلك صورة - على الأنظمة المدعومة - أو إدخال نص أو حتى لا شيء على الإطلاق.
</p>

<p dir="rtl" lang="ar">
يكتشف تلقائياً التراخيص مفتوحة المصدر من النصوص، ويزود المستخدم بمعلومات قيمة مثل توزيع الكود، التغييرات المعلقة، عدد التبعيات (بواسطة مدير الحزم)، المساهمين الأساسين (حسب عدد الالتزامات)، وحجم المستودع علي القرص الصلب، وتاريخ الإنشاء،
LOC
(عدد أسطر الكود)، إلخ.
</p>

<img src="../assets/screenshot-2.png" align="left" height="240px">

<p dir="rtl" lang="ar">
يمكن تكوين
Onefetch
عن طريق معلمات سطر الأوامر
(Flags)
لعرض ما تريده بالضبط، بالطريقة التي تريدها.
يمكنك تخصيص تنسيق النص/
ASCII
، وتعطيل المعلومات التي لا تهمك، وتجاهل الملفات والمجلدات، وإخراج النتائج بتنسيقات مختلفة
مثل
(Json, Yaml)
إلخ.
</p>

<p dir="rtl" lang="ar">
حتى الآن، يدعم
Onefetch
أكثر من
<a href="https://onefetch.dev">100 لغة برمجة مختلفة</a>
؛ إذا لم تكن لغتك المفضلة مدعومة: افتح مشكلة وسيتم إضافة الدعم.
</p>

<p dir="rtl" lang="ar">
المساهمات مرحب بها جداً جداً جداً! انظر
<a href="../CONTRIBUTING.md">دليل المساهمة</a>
لمزيد من المعلومات.
</p>

### المزيد: \[[ويكي](https://github.com/o2sh/onefetch/wiki)\] \[[التثبيت](https://github.com/o2sh/onefetch/wiki/Installation)\] \[[البدء](https://github.com/o2sh/onefetch/wiki/getting-started)\]

==> onefetch-2.17.0.tar.gz: onefetch-2.17.0/docs/README.ar.md <==
<h3 align="center"><img src="../assets/onefetch.svg" height="130px"></h3>

<h5 align="center">Rust مكتوبه بالغة GIT أداة سطر الأوامر لعرض معلومات مستودع</h5>

<p align="center">
	<a href="https://crates.io/crates/onefetch"><img src="https://img.shields.io/crates/v/onefetch.svg" alt="cargo"></a>
	<a href="https://github.com/o2sh/onefetch/actions"><img src="https://github.com/o2sh/onefetch/workflows/CI/badge.svg" alt="Build Status"></a>
  <a href="https://onefetch.dev"><img src="../assets/language-badge.svg"></a>
	<a href="https://github.com/o2sh/onefetch/issues?q=is%3Aissue+is%3Aopen+label%3A%22%E2%9D%93+help+wanted%22"><img src="https://img.shields.io/github/issues/o2sh/onefetch/%E2%9D%93%20help%20wanted?color=green" alt="help wanted"></a>
	<a href="../LICENSE.md"><img src="https://img.shields.io/badge/license-MIT-blue.svg"></a>
	<img src="../assets/msrv-badge.svg">
</p>

<img src="../assets/screenshot-1.png" align="left" height="240px">

<p dir="rtl" lang="ar">
Onefetch
هي أداة سطر الأوامر مكتوبة بالغة
Rust
تعرض معلومات المشروع وإحصائيات الكود لمستودع
Git
.المحلي مباشرة الي جهازك الطرفي
الأداة مستقلة تمامًا عن الإنترنت - لا يتطلب الوصول إلى الشبكة.
</p>

<p dir="rtl" lang="ar">
يتم عرض معلومات المستودع جنباً إلي جنب مع شعار اللغة السائدة في المشروع بشكل إفتراضي، ولكن يمكنك أيضاً تكوين
Onefetch
بحيث يستخدم بدلاً من ذلك صورة - على الأنظمة المدعومة - أو إدخال نص أو حتى لا شيء على الإطلاق.
</p>

<p dir="rtl" lang="ar">
يكتشف تلقائياً التراخيص مفتوحة المصدر من النصوص، ويزود المستخدم بمعلومات قيمة مثل توزيع الكود، التغييرات المعلقة، عدد التبعيات (بواسطة مدير الحزم)، المساهمين الأساسين (حسب عدد الالتزامات)، وحجم المستودع علي القرص الصلب، وتاريخ الإنشاء،
LOC
(عدد أسطر الكود)، إلخ.
</p>

<img src="../assets/screenshot-2.png" align="left" height="240px">

<p dir="rtl" lang="ar">
يمكن تكوين
Onefetch
عن طريق معلمات سطر الأوامر
(Flags)
لعرض ما تريده بالضبط، بالطريقة التي تريدها.
يمكنك تخصيص تنسيق النص/
ASCII
، وتعطيل المعلومات التي لا تهمك، وتجاهل الملفات والمجلدات، وإخراج النتائج بتنسيقات مختلفة
مثل
(Json, Yaml)
إلخ.
</p>

<p dir="rtl" lang="ar">
حتى الآن، يدعم
Onefetch
أكثر من
<a href="https://onefetch.dev">100 لغة برمجة مختلفة</a>
؛ إذا لم تكن لغتك المفضلة مدعومة: افتح مشكلة وسيتم إضافة الدعم.
</p>

<p dir="rtl" lang="ar">
المساهمات مرحب بها جداً جداً جداً! انظر
<a href="../CONTRIBUTING.md">دليل المساهمة</a>
لمزيد من المعلومات.
</p>

### المزيد: \[[ويكي](https://github.com/o2sh/onefetch/wiki)\] \[[التثبيت](https://github.com/o2sh/onefetch/wiki/Installation)\] \[[البدء](https://github.com/o2sh/onefetch/wiki/getting-started)\]
